# Generated by Django 2.1.5 on 2019-02-01 04:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0004_add_esp_id")]

    operations = [
        migrations.AlterField(
            model_name="campaignsentevent",
            name="esp_message_id",
            field=models.CharField(
                max_length=255,
                null=True,
                unique=True,
                verbose_name="ID given by the sending server",
            ),
        ),
        migrations.AlterField(
            model_name="campaignsentevent",
            name="result",
            field=models.CharField(
                choices=[
                    ("P", "Sending"),
                    ("?", "Unknown"),
                    ("RE", "Rejected by server"),
                    ("OK", "Sent"),
                    ("BC", "Bounced"),
                    ("C", "Complained"),
                    ("U", "Unsubscribed"),
                    ("BL", "Blocked temporarily"),
                    ("E", "Error"),
                ],
                default="P",
                max_length=2,
                verbose_name="Operation result",
            ),
        ),
    ]
